#
# spec file for package moolticute
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global UDEVDIR %{_udevrulesdir}
%global QMAKE_BIN qmake-qt5
Name:           moolticute
Version:        1.02.0.r0.gc4e4886
Release:        1.3
Summary:        Companion GUI application for Mooltipass password manager devices
License:        GPL-3.0-only
URL:            https://github.com/mooltipass/moolticute
Source0:        %{name}-%{version}.tar.gz
Source1:        69-mooltipass.rules
Source2:        README.SUSE
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libudev)
Conflicts:      moolticute-testing

%description
This project aims to be an easy to use companion to your Mooltipass device and extend the power of the device to more platform/tools. With it you can manage your Mooltipass with a cross-platform app, as well as provide a daemon service that handles all USB communication with the device. This tool comes with a daemon that runs in background, and a user interface app to control your Mooltipass. Other clients can also connect and talk to the daemon (it uses a websocket connection and simple JSON messages). It is completely cross platform, and runs on Linux (using native hidraw API), OS X (native IOKit API), and Windows (native HID API).

%prep
%autosetup

%build
%{QMAKE_BIN} PREFIX=%{_prefix} DESTDIR= Moolticute.pro
%make_build sub-daemon-pro-all sub-gui-pro-all

%install
install -d 555 %{buildroot}%{_sbindir}
install -d 555 %{buildroot}%{_bindir}
install -d 755 %{buildroot}%{UDEVDIR}
install -m 644 %{_sourcedir}/69-mooltipass.rules %{buildroot}%{UDEVDIR}/.

%make_install PREFIX=%{_prefix} INSTALL_ROOT=%{buildroot}

ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcmoolticuted

install -m 644 -D %{SOURCE2} %{buildroot}%{_docdir}/%{name}/README.SUSE

%files
%license LICENSE
%{_bindir}/moolticute
%{_bindir}/moolticuted
%{UDEVDIR}/69-mooltipass.rules
%{_sbindir}/rcmoolticuted
%{_prefix}/lib/systemd/system/moolticuted.service
%{_datadir}/applications/moolticute.desktop
%{_datadir}/icons/hicolor/128x128/apps/moolticute.png
%{_datadir}/icons/hicolor/32x32/apps/moolticute.png
%{_datadir}/icons/hicolor/scalable/apps/moolticute.svg
%{_datadir}/icons/hicolor/scalable
%{_datadir}/icons/hicolor/scalable/apps
%dir %{_docdir}/moolticute
%{_docdir}/moolticute/README.SUSE

%pre
%service_add_pre moolticuted.service

%post
%service_add_post moolticuted.service

%preun
%service_del_preun moolticuted.service

%postun
%service_del_postun moolticuted.service

%changelog
* Thu Sep 28 2023 Bob Haley <fawz@use.startmail.com>
- Update to v1.02.0
    [BLE] Fetch and send password for special no bundle upload
    Remove duplicate service check during import, fix #1148
    [BLE] Remove empty service during integrity check
    Change Credential save error message to more specific, fix #1021
    Prevent Linux Mint dark mode readability issues, fix #1158
    Remove CTRL from shortcut displayed on Advanced tab
    Fix Login and Password length limit for credentials edit
    Fix Login and Password length limit on Credentials tab
    [BLE] Decrease notes images, increase font size
    [BLE] Protect note fetch from parallel fetches, fix #1151
    [BLE] Remove Enabled/Disabled text for BT and Knock detection
    build for ubuntu 23.04
    [BLE] Handle email address during adding credential
    [BLE] Add improve battery life text to disable BLE setting (bundle v13)
    [BLE] Improve notes label name display
    [BLE] Send wake up device when credential requested and device is locked
    Add copy to clipboard for password generation
    [BLE] Add new device settings (paranoid pin entry, battery charge disable - bundle v13)
    [BLE] Fix fetch password for multiple domains
    [BLE] Fix password change for multiple domains
    Handle new tld for existing multiple domain service
    Set password generator length based on device, fix #1174
    [BLE] Add option to continue recondition
* Thu Jun 29 2023 Stefan Weiberg <opensuse@hibiki.eu>
- Update to v1.01.0
    [BLE] Remove not tagged notes during import
    [BLE] Fetch notes after import
    [BLE] Fix import data nodes
    [BLE] Display when entered multiple domain is invalid
    [BLE] Fix multiple low battery notification
    [BLE] Improve NoBundle FW upload
    Fix application exit on Mac
    bug fix: in a "no bundle" case, allow moolticute to fetch platform info
    Mini BLE: increase file size to 20kB
    Fix saving credential without passwords Qt6
    changing hidden tabs shortcuts to SHIFT + Fx
    increasing daemon log size
    Mini: fix files upload
* Thu Dec  1 2022 Bob Haley <fawz@use.startmail.com>
- Update to v1.00.1
    credential fetching bug fix
- Changelog from v1.00.0
    Matches bundle v12 release
    Built with QT6 on Mac & Windows
  * All devices changelog:
    minimize on cmd+q on MacOS
  * Mini BLE changelog:
    change BLE name
    credential mirroring feature
    multiple domain support
    TOTP setting bug fix
    monospaced font for notes
    allow reprogramming of "soft serial numbers" for non programmed units
    hide save button for clean categories
    bug fix: preventing continuous queries when the card is suddenly removed
    fix Qt6 MMM filter remove display issue
    fix xenial/bionic Qt related build issue
    notes not fetched bug fix
  * New settings:
    on-screen OTP display after login into website
    login menu: start from last used service
    switch off after BLE disconnect
    sort favorites by last used date
    allocated for MC, specify subdomain status on device
    custom delay between enter key and password for unlock
    screen brightness setting
    subdomain setting enforcement
    get TOTP message
    category enforcement
    Invert Login And Favorites Icons
* Thu Oct 13 2022 Johannes Segitz <jsegitz@suse.com>
- Add README.SUSE to make users aware of potential security issues
  (bsc#1202928)
- Ran spec-cleaner on the spec file
* Tue May 31 2022 Stefan Weiberg <sweiberg@suse.com>
- Update to v0.55.0
  * All:
    fix gnome on wayland crash
    smaller window for small resolution screens
    bug fix: mc-agent executable correct path
    bug fix: Fix crash during service name change
    better focus assist detection
    simpler key combination for secret tabs on mac (ctrl+f1/f2/f3)
    bug fix: Fix delete and rename account to the same name in MMM
    Enable to rename login to empty string in MMM
    Prevent changing login name to an existing one in MMM
    Disable export db prompt when there is no monitored file
    Do not save not confirmed changes when exiting MMM
    bug fix: integrity check with orphan children nodes
    duplicate service check in MMM
  * BLE:
    automatic bundle file parsing & password recognition
    correct error message when not approving prompts after MMM
    prompts for bundle version for v7
* Tue May 18 2021 fawz <fawz@negentropy.io>
- Add Maintainer field for debbuild builds
- Fix typo in summary field
* Wed May 12 2021 fawz <fawz@negentropy.io>
- Debian_10 support
* Sun May  9 2021 fawz <fawz@negentropy.io>
- Initial package for OpenSUSE Tumbleweed.
